import uuid

from dataclasses import dataclass, field

@dataclass
class EquipmentClass:

  name: str
  active: bool = field(default=False)
  # generated by server and returned
  id: uuid.UUID = field(default=None)